@@ -19,6 +19,14 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #define pr_fmt(fmt)	KBUILD_MODNAME ": " fmt
 
 #include <linux/version.h>
+#if LINUX_VERSION_CODE <= KERNEL_VERSION(2, 6, 20)
+#include <linux/kobject.h>
+#include <trace/sched.h>
+#include "ppm_syscall.h"
+#include <trace/syscall.h>
+#else
+#include <asm/syscall.h>
+#endif
 #if (LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 37))
 #include <asm/atomic.h>
 #else
@@ -34,9 +42,10 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #include <linux/vmalloc.h>
 #include <linux/wait.h>
 #include <linux/tracepoint.h>
+#include <linux/cpu.h>
 #include <linux/jiffies.h>
-#include <asm/syscall.h>
 #include <net/sock.h>
+#include <asm/asm-offsets.h>	/* For NR_syscalls */
 
 #include <asm/unistd.h>
 
@@ -155,10 +164,14 @@ static DEFINE_MUTEX(g_consumer_mutex);
 static bool g_tracepoint_registered;
 
 struct cdev *g_ppe_cdev = NULL;
-struct device *g_ppe_dev = NULL;
-
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 static struct tracepoint *tp_sys_enter;
 static struct tracepoint *tp_sys_exit;
+struct device *g_ppe_dev = NULL;
+#else
+struct class_device *g_ppe_dev = NULL;
+#endif
+
 static struct tracepoint *tp_sched_process_exit;
 #ifdef CAPTURE_CONTEXT_SWITCHES
 static struct tracepoint *tp_sched_switch;
@@ -221,7 +234,7 @@ static void check_remove_consumer(struct ppm_consumer_t *consumer, int remove_fr
 	int cpu;
 	int open_rings = 0;
 
-	for_each_online_cpu(cpu) {
+	for_each_possible_cpu(cpu) {
 		struct ppm_ring_buffer_context *ring = per_cpu_ptr(consumer->ring_buffers, cpu);
 		if (ring && ring->open)
 			++open_rings;
@@ -235,15 +248,16 @@ static void check_remove_consumer(struct ppm_consumer_t *consumer, int remove_fr
 			synchronize_rcu();
 		}
 
-		for_each_online_cpu(cpu) {
+		for_each_possible_cpu(cpu) {
 			struct ppm_ring_buffer_context *ring = per_cpu_ptr(consumer->ring_buffers, cpu);
 
-			if (ring)
+			if (ring->cpu_online)
 				free_ring_buffer(ring);
 		}
 
 		free_percpu(consumer->ring_buffers);
 
+		kfree(consumer->proclist_info);
 		vfree(consumer);
 	}
 }
@@ -255,10 +269,14 @@ static int ppm_open(struct inode *inode, struct file *filp)
 {
 	int ret;
 	int in_list = false;
-	struct ppm_ring_buffer_context *ring = NULL;
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 	int ring_no = iminor(filp->f_path.dentry->d_inode);
+#else
+	int ring_no = iminor(filp->f_dentry->d_inode);
+#endif
 	struct task_struct *consumer_id = current;
 	struct ppm_consumer_t *consumer = NULL;
+	struct ppm_ring_buffer_context *ring = NULL;
 
 	/*
 	 * Tricky: to identify a consumer, attach the thread id
@@ -296,6 +314,7 @@ static int ppm_open(struct inode *inode, struct file *filp)
 		}
 
 		consumer->consumer_id = consumer_id;
+		consumer->proclist_info = NULL;
 
 		/*
 		 * Initialize the ring buffers array
@@ -310,22 +329,34 @@ static int ppm_open(struct inode *inode, struct file *filp)
 			goto cleanup_open;
 		}
 
-		for_each_online_cpu(cpu) {
-			struct ppm_ring_buffer_context *ring = per_cpu_ptr(consumer->ring_buffers, cpu);
+		/*
+		 * Note, we have two loops here because the first one makes sure that ALL of the
+		 * rings are properly initialized to null, since the second one could be interrupted
+		 * and cause issues in the cleanup phase.
+		 * This might not be necessary, because alloc_percpu memsets the allocated entries to
+		 * 0, but better be extra safe.
+		 */
+		for_each_possible_cpu(cpu) {
+			ring = per_cpu_ptr(consumer->ring_buffers, cpu);
 
+			ring->cpu_online = false;
 			ring->str_storage = NULL;
 			ring->buffer = NULL;
 			ring->info = NULL;
 		}
 
 		for_each_online_cpu(cpu) {
+			ring = per_cpu_ptr(consumer->ring_buffers, cpu);
+
 			pr_info("initializing ring buffer for CPU %u\n", cpu);
 
-			if (!init_ring_buffer(per_cpu_ptr(consumer->ring_buffers, cpu))) {
+			if (!init_ring_buffer(ring)) {
 				pr_err("can't initialize the ring buffer for CPU %u\n", cpu);
 				ret = -ENOMEM;
 				goto err_init_ring_buffer;
 			}
+
+			ring->cpu_online = true;
 		}
 
 		list_add_rcu(&consumer->node, &g_consumer_list);
@@ -336,6 +367,15 @@ static int ppm_open(struct inode *inode, struct file *filp)
 
 	ring = per_cpu_ptr(consumer->ring_buffers, ring_no);
 
+	/*
+	 * Check if the CPU pointed by this device is online. If it isn't stop here and
+	 * return ENODEV.
+	 */
+	if (ring->cpu_online == false) {
+		ret = -ENODEV;
+		goto cleanup_open;
+	}
+
 	if (ring->open) {
 		pr_err("invalid operation: attempting to open device %d multiple times for consumer %p\n", ring_no, consumer->consumer_id);
 		ret = -EBUSY;
@@ -377,13 +417,22 @@ static int ppm_open(struct inode *inode, struct file *filp)
 		/*
 		 * Enable the tracepoints
 		 */
+
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 		ret = compat_register_trace(syscall_exit_probe, "sys_exit", tp_sys_exit);
+#else
+		ret = register_trace_syscall_enter(syscall_enter_probe);
+#endif
 		if (ret) {
 			pr_err("can't create the sys_exit tracepoint\n");
 			goto err_sys_exit;
 		}
 
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 		ret = compat_register_trace(syscall_enter_probe, "sys_enter", tp_sys_enter);
+#else
+		ret = register_trace_syscall_exit(syscall_exit_probe);
+#endif
 		if (ret) {
 			pr_err("can't create the sys_enter tracepoint\n");
 			goto err_sys_enter;
@@ -424,9 +473,17 @@ err_signal_deliver:
 err_sched_switch:
 	compat_unregister_trace(syscall_procexit_probe, "sched_process_exit", tp_sched_process_exit);
 err_sched_procexit:
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 	compat_unregister_trace(syscall_enter_probe, "sys_enter", tp_sys_enter);
+#else
+	unregister_trace_syscall_enter(syscall_enter_probe);
+#endif
 err_sys_enter:
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 	compat_unregister_trace(syscall_exit_probe, "sys_exit", tp_sys_exit);
+#else
+	unregister_trace_syscall_exit(syscall_exit_probe);
+#endif
 err_sys_exit:
 	ring->open = false;
 err_init_ring_buffer:
@@ -441,7 +498,11 @@ static int ppm_release(struct inode *inode, struct file *filp)
 {
 	int ret;
 	struct ppm_ring_buffer_context *ring;
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 	int ring_no = iminor(filp->f_path.dentry->d_inode);
+#else
+	int ring_no = iminor(filp->f_dentry->d_inode);
+#endif
 	struct task_struct *consumer_id = filp->private_data;
 	struct ppm_consumer_t *consumer = NULL;
 
@@ -455,6 +516,11 @@ static int ppm_release(struct inode *inode, struct file *filp)
 	}
 
 	ring = per_cpu_ptr(consumer->ring_buffers, ring_no);
+	if (!ring) {
+		ASSERT(false);
+		ret = -ENODEV;
+		goto cleanup_release;
+	}
 
 	if (!ring->open) {
 		pr_err("attempting to close unopened device %d for consumer %p\n", ring_no, consumer_id);
@@ -484,8 +550,13 @@ static int ppm_release(struct inode *inode, struct file *filp)
 		if (g_tracepoint_registered) {
 			pr_info("no more consumers, stopping capture\n");
 
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 			compat_unregister_trace(syscall_exit_probe, "sys_exit", tp_sys_exit);
 			compat_unregister_trace(syscall_enter_probe, "sys_enter", tp_sys_enter);
+#else
+			unregister_trace_syscall_exit(syscall_exit_probe);
+			unregister_trace_syscall_enter(syscall_enter_probe);
+#endif
 			compat_unregister_trace(syscall_procexit_probe, "sched_process_exit", tp_sched_process_exit);
 
 #ifdef CAPTURE_CONTEXT_SWITCHES
@@ -494,7 +565,9 @@ static int ppm_release(struct inode *inode, struct file *filp)
 #ifdef CAPTURE_SIGNAL_DELIVERIES
 			compat_unregister_trace(signal_deliver_probe, "signal_deliver", tp_signal_deliver);
 #endif
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 			tracepoint_synchronize_unregister();
+#endif
 			g_tracepoint_registered = false;
 		} else {
 			ASSERT(false);
@@ -527,8 +600,16 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 	switch (cmd) {
 	case PPM_IOCTL_DISABLE_CAPTURE:
 	{
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 		int ring_no = iminor(filp->f_path.dentry->d_inode);
+#else
+		int ring_no = iminor(filp->f_dentry->d_inode);
+#endif
 		struct ppm_ring_buffer_context *ring = per_cpu_ptr(consumer->ring_buffers, ring_no);
+		if (!ring) {
+			ASSERT(false);
+			return -ENODEV;
+		}
 
 		ring->capture_enabled = false;
 
@@ -539,8 +620,16 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 	}
 	case PPM_IOCTL_ENABLE_CAPTURE:
 	{
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 		int ring_no = iminor(filp->f_path.dentry->d_inode);
+#else
+		int ring_no = iminor(filp->f_dentry->d_inode);
+#endif
 		struct ppm_ring_buffer_context *ring = per_cpu_ptr(consumer->ring_buffers, ring_no);
+		if (!ring) {
+			ASSERT(false);
+			return -ENODEV;
+		}
 
 		ring->capture_enabled = true;
 
@@ -681,6 +770,7 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 		ret = 0;
 		goto cleanup_ioctl;
 	}
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 	case PPM_IOCTL_GET_VTID:
 	case PPM_IOCTL_GET_VPID:
 	{
@@ -691,7 +781,7 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 
 		rcu_read_lock();
 		pid = find_pid_ns(arg, &init_pid_ns);
-		if(!pid) {
+		if (!pid) {
 			rcu_read_unlock();
 			ret = -EINVAL;
 			goto cleanup_ioctl;
@@ -705,13 +795,13 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 		}
 
 		ns = ns_of_pid(pid);
-		if(!pid) {
+		if (!pid) {
 			rcu_read_unlock();
 			ret = -EINVAL;
 			goto cleanup_ioctl;
 		}
 
-		if(cmd == PPM_IOCTL_GET_VTID)
+		if (cmd == PPM_IOCTL_GET_VTID)
 			vid = task_pid_nr_ns(task, ns);
 		else
 			vid = task_tgid_nr_ns(task, ns);
@@ -720,17 +810,20 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 		ret = vid;
 		goto cleanup_ioctl;
 	}
+#endif
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 	case PPM_IOCTL_GET_CURRENT_TID:
 		ret = task_pid_nr(current);
 		goto cleanup_ioctl;
 	case PPM_IOCTL_GET_CURRENT_PID:
 		ret = task_tgid_nr(current);
 		goto cleanup_ioctl;
+#endif /* LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20) */
 #ifdef CAPTURE_SIGNAL_DELIVERIES
 	case PPM_IOCTL_DISABLE_SIGNAL_DELIVER:
 	{
 		vpr_info("PPM_IOCTL_DISABLE_SIGNAL_DELIVER\n");
-		if (g_tracepoint_registered) 
+		if (g_tracepoint_registered)
 			compat_unregister_trace(signal_deliver_probe, "signal_deliver", tp_signal_deliver);
 		ret = 0;
 		goto cleanup_ioctl;
@@ -748,18 +841,32 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 	{
 		struct task_struct *p, *t;
 		u64 nentries = 0;
-		struct ppm_proclist_info* pli;
-		struct ppm_proc_info pi;
+		struct ppm_proclist_info pli;
+		u32 memsize;
 
-		if (copy_from_user(&pli, (void*)arg, sizeof(pli))) {
+		if (copy_from_user(&pli, (void *)arg, sizeof(pli))) {
 			ret = -EINVAL;
 			goto cleanup_ioctl;
 		}
 
-		vpr_info("PPM_IOCTL_GET_PROCLIST, size=%d\n", (int)pli->max_entries);
+		vpr_info("PPM_IOCTL_GET_PROCLIST, size=%d\n", (int)pli.max_entries);
+
+		if (consumer->proclist_info == NULL || consumer->proclist_info->max_entries != pli.max_entries) {
+			if (consumer->proclist_info != NULL)
+				kfree(consumer->proclist_info);
+
+			memsize = sizeof(struct ppm_proclist_info) + sizeof(struct ppm_proc_info) * pli.max_entries;
+			consumer->proclist_info = kmalloc(memsize, GFP_KERNEL);
+			if (!consumer->proclist_info) {
+				ret = -EINVAL;
+				goto cleanup_ioctl;
+			}
+
+			consumer->proclist_info->max_entries = pli.max_entries;
+		}
 
 		rcu_read_lock();
-		
+
 #ifdef for_each_process_thread
 		for_each_process_thread(p, t) {
 #else
@@ -768,7 +875,7 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 			do {
 				task_lock(p);
 #endif
-				if (nentries < pli->max_entries) {
+				if (nentries < pli.max_entries) {
 					cputime_t utime, stime;
 
 #if (LINUX_VERSION_CODE < KERNEL_VERSION(3, 9, 0))
@@ -777,15 +884,9 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 #else
 					ppm_task_cputime_adjusted(t, &utime, &stime);
 #endif
-					pi.pid = t->pid;
-					pi.utime = cputime_to_clock_t(utime);
-					pi.stime = cputime_to_clock_t(stime);
-
-					if (copy_to_user((void*)&pli->entries[nentries], &pi, sizeof(struct ppm_proc_info))) {
-						rcu_read_unlock();
-						ret = -EINVAL;
-						goto cleanup_ioctl;
-					}
+					consumer->proclist_info->entries[nentries].pid = t->pid;
+					consumer->proclist_info->entries[nentries].utime = cputime_to_clock_t(utime);
+					consumer->proclist_info->entries[nentries].stime = cputime_to_clock_t(stime);
 				}
 
 				nentries++;
@@ -799,18 +900,27 @@ static long ppm_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 
 		rcu_read_unlock();
 
-		if (copy_to_user((void*)&pli->n_entries, &nentries, sizeof(pli->n_entries))) {
-			ret = -EINVAL;
-			goto cleanup_ioctl;
-		}
+		consumer->proclist_info->n_entries = nentries;
 
-		if (nentries >= pli->max_entries) {
-			vpr_info("PPM_IOCTL_GET_PROCLIST: not enough space (%d avail, %d required)\n", 
-				(int)pli->max_entries,
+		if (nentries >= pli.max_entries) {
+			vpr_info("PPM_IOCTL_GET_PROCLIST: not enough space (%d avail, %d required)\n",
+				(int)pli.max_entries,
 				(int)nentries);
 
+			if (copy_to_user((void *)arg, consumer->proclist_info, sizeof(struct ppm_proclist_info))) {
+				ret = -EINVAL;
+				goto cleanup_ioctl;
+			}
+
 			ret = -ENOSPC;
 			goto cleanup_ioctl;
+		} else {
+			memsize = sizeof(struct ppm_proclist_info) + sizeof(struct ppm_proc_info) * nentries;
+
+			if (copy_to_user((void *)arg, consumer->proclist_info, memsize)) {
+				ret = -EINVAL;
+				goto cleanup_ioctl;
+			}
 		}
 
 		ret = 0;
@@ -848,7 +958,11 @@ static int ppm_mmap(struct file *filp, struct vm_area_struct *vma)
 		unsigned long pfn;
 		char *vmalloc_area_ptr;
 		char *orig_vmalloc_area_ptr;
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 		int ring_no = iminor(filp->f_path.dentry->d_inode);
+#else
+		int ring_no = iminor(filp->f_dentry->d_inode);
+#endif
 		struct ppm_ring_buffer_context *ring;
 
 		vpr_info("mmap for consumer %p, CPU %d, start=%lu len=%ld page_size=%lu\n",
@@ -879,6 +993,10 @@ static int ppm_mmap(struct file *filp, struct vm_area_struct *vma)
 		 * Retrieve the ring structure for this CPU
 		 */
 		ring = per_cpu_ptr(consumer->ring_buffers, ring_no);
+		if (!ring) {
+			ASSERT(false);
+			return -ENODEV;
+		}
 
 		if (length <= PAGE_SIZE) {
 			/*
@@ -1031,7 +1149,7 @@ static enum ppm_event_type parse_socketcall(struct event_filler_arguments *fille
 	case SYS_LISTEN:
 		return PPME_SOCKET_LISTEN_E;
 	case SYS_ACCEPT:
-		return PPME_SOCKET_ACCEPT_E;
+		return PPME_SOCKET_ACCEPT_5_E;
 	case SYS_GETSOCKNAME:
 		return PPME_SOCKET_GETSOCKNAME_E;
 	case SYS_GETPEERNAME:
@@ -1065,7 +1183,7 @@ static enum ppm_event_type parse_socketcall(struct event_filler_arguments *fille
 		return PPME_SOCKET_RECVMMSG_E;
 #endif
 	case SYS_ACCEPT4:
-		return PPME_SOCKET_ACCEPT4_E;
+		return PPME_SOCKET_ACCEPT4_5_E;
 	default:
 		ASSERT(false);
 		return PPME_GENERIC_E;
@@ -1076,6 +1194,7 @@ static enum ppm_event_type parse_socketcall(struct event_filler_arguments *fille
 static inline void record_drop_e(struct ppm_consumer_t *consumer, struct timespec *ts)
 {
 	struct event_data_t event_data = {0};
+
 	if (record_event_consumer(consumer, PPME_DROP_E, UF_NEVER_DROP, ts, &event_data) == 0) {
 		consumer->need_to_insert_drop_e = 1;
 	} else {
@@ -1089,6 +1208,7 @@ static inline void record_drop_e(struct ppm_consumer_t *consumer, struct timespe
 static inline void record_drop_x(struct ppm_consumer_t *consumer, struct timespec *ts)
 {
 	struct event_data_t event_data = {0};
+	
 	if (record_event_consumer(consumer, PPME_DROP_X, UF_NEVER_DROP, ts, &event_data) == 0) {
 		consumer->need_to_insert_drop_x = 1;
 	} else {
@@ -1156,7 +1276,7 @@ static int record_event_consumer(struct ppm_consumer_t *consumer,
 	struct event_data_t *event_datap)
 {
 	int res = 0;
-	size_t event_size;
+	size_t event_size = 0;
 	int next;
 	u32 freespace;
 	u32 usedspace;
@@ -1188,6 +1308,8 @@ static int record_event_consumer(struct ppm_consumer_t *consumer,
 	 */
 	cpu = get_cpu();
 	ring = per_cpu_ptr(consumer->ring_buffers, cpu);
+	ASSERT(ring);
+
 	ring_info = ring->info;
 
 	if (!ring->capture_enabled) {
@@ -1197,10 +1319,9 @@ static int record_event_consumer(struct ppm_consumer_t *consumer,
 
 	ring_info->n_evts++;
 	if (event_datap->category == PPMC_CONTEXT_SWITCH && event_datap->event_info.context_data.sched_prev != NULL) {
-		if (event_type != PPME_SYSDIGEVENT_E) {
+		if (event_type != PPME_SYSDIGEVENT_E && event_type != PPME_CPU_HOTPLUG_E) {
 			ASSERT(event_datap->event_info.context_data.sched_prev != NULL);
 			ASSERT(event_datap->event_info.context_data.sched_next != NULL);
-			//ASSERT(regs == NULL);
 			ring_info->n_context_switches++;
 		}
 	} else if (event_datap->category == PPMC_SIGNAL) {
@@ -1545,7 +1666,11 @@ TRACEPOINT_PROBE(syscall_procexit_probe, struct task_struct *p)
 {
 	struct event_data_t event_data;
 
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 	if (unlikely(current->flags & PF_KTHREAD)) {
+#else
+	if (unlikely(current->flags & PF_BORROWED_MM)) {
+#endif
 		/*
 		 * We are not interested in kernel threads
 		 */
@@ -1571,6 +1696,7 @@ TRACEPOINT_PROBE(sched_switch_probe, struct task_struct *prev, struct task_struc
 #endif
 {
 	struct event_data_t event_data;
+
 	event_data.category = PPMC_CONTEXT_SWITCH;
 	event_data.event_info.context_data.sched_prev = prev;
 	event_data.event_info.context_data.sched_next = next;
@@ -1727,6 +1853,7 @@ static int get_tracepoint_handles(void)
 }
 #endif
 
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 3, 0)
 static char *ppm_devnode(struct device *dev, umode_t *mode)
 #else
@@ -1743,6 +1870,71 @@ static char *ppm_devnode(struct device *dev, mode_t *mode)
 
 	return NULL;
 }
+#endif /* LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20) */
+
+/*
+ * This gets called every time a CPU is added or removed
+ */
+static int cpu_callback(struct notifier_block *self, unsigned long action,
+			void *hcpu)
+{
+	long cpu = (long)hcpu;
+	struct ppm_ring_buffer_context *ring;
+	struct ppm_consumer_t *consumer;
+	bool event_recorded = false;
+	struct timespec ts;
+	struct event_data_t event_data;
+	long sd_action = 0;
+
+	switch (action) {
+	case CPU_UP_PREPARE:
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
+	case CPU_UP_PREPARE_FROZEN:
+#endif	
+		sd_action = 1;
+		break;
+	case CPU_DOWN_PREPARE:
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
+	case CPU_DOWN_PREPARE_FROZEN:
+#endif
+		sd_action = 2;
+		break;
+	default:
+		break;
+	}
+
+	/*
+	 * Based on the action, spit an event in the first available ring
+	 */
+	if (sd_action != 0) {
+		rcu_read_lock();
+
+		list_for_each_entry_rcu(consumer, &g_consumer_list, node) {
+			ring = per_cpu_ptr(consumer->ring_buffers, cpu);
+			ring->capture_enabled = false;
+
+			getnstimeofday(&ts);
+
+			event_data.category = PPMC_CONTEXT_SWITCH;
+			event_data.event_info.context_data.sched_prev = (void *)cpu;
+			event_data.event_info.context_data.sched_next = (void *)sd_action;
+
+			if (!event_recorded) {
+				record_event_consumer(consumer, PPME_CPU_HOTPLUG_E, UF_NEVER_DROP, &ts, &event_data);
+				event_recorded = true;
+			}
+		}
+
+		rcu_read_unlock();
+	}
+
+	return NOTIFY_DONE;
+}
+
+static struct notifier_block cpu_notifier = {
+	.notifier_call = &cpu_callback,
+	.next = NULL,
+};
 
 int sysdig_init(void)
 {
@@ -1753,8 +1945,11 @@ int sysdig_init(void)
 	int acrret = 0;
 	int j;
 	int n_created_devices = 0;
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 	struct device *device = NULL;
-
+#else
+	struct class_device *device = NULL;
+#endif
 	pr_info("driver loading\n");
 
 	ret = get_tracepoint_handles();
@@ -1762,7 +1957,7 @@ int sysdig_init(void)
 		goto init_module_err;
 
 	num_cpus = 0;
-	for_each_online_cpu(cpu) {
+	for_each_possible_cpu(cpu) {
 		++num_cpus;
 	}
 
@@ -1784,7 +1979,9 @@ int sysdig_init(void)
 		goto init_module_err;
 	}
 
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 	g_ppm_class->devnode = ppm_devnode;
+#endif
 
 	g_ppm_major = MAJOR(dev);
 	g_ppm_numdevs = num_cpus;
@@ -1808,11 +2005,16 @@ int sysdig_init(void)
 			goto init_module_err;
 		}
 
-		device = device_create(g_ppm_class, NULL, /* no parent device */
-				       g_ppm_devs[j].dev,
-				       NULL, /* no additional data */
-				       PPM_DEVICE_NAME "%d",
-				       j);
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
+		device = device_create(
+#else
+		device = class_device_create(
+#endif
+						g_ppm_class, NULL, /* no parent device */
+						g_ppm_devs[j].dev,
+						NULL, /* no additional data */
+						PPM_DEVICE_NAME "%d",
+						j);
 
 		if (IS_ERR(device)) {
 			pr_err("error creating the device for  %s\n", PPM_DEVICE_NAME);
@@ -1842,13 +2044,18 @@ int sysdig_init(void)
 		goto init_module_err;
 	}
 
-	g_ppe_dev = device_create(g_ppm_class, NULL,
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
+	g_ppe_dev = device_create(
+#else
+	g_ppe_dev = class_device_create(
+#endif
+			g_ppm_class, NULL,
 			MKDEV(g_ppm_major, g_ppm_numdevs),
 			NULL, /* no additional data */
 			PPE_DEVICE_NAME);
 
 	if (IS_ERR(g_ppe_dev)) {
-		pr_err("error creating the device for  %s\n", PPE_DEVICE_NAME);
+		pr_err("error creating the device for %s\n", PPE_DEVICE_NAME);
 		ret = -EFAULT;
 		goto init_module_err;
 	}
@@ -1862,6 +2069,12 @@ int sysdig_init(void)
 		goto init_module_err;
 	}
 
+	/*
+	 * Set up our callback in case we get a hotplug even while we are 
+	 * initializing the cpu structures
+	 */
+	register_cpu_notifier(&cpu_notifier);
+
 	/*
 	 * All ok. Final initalizations.
 	 */
@@ -1917,12 +2130,18 @@ void sysdig_exit(void)
 
 	kfree(g_ppm_devs);
 
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 	tracepoint_synchronize_unregister();
+#endif
+
+	unregister_cpu_notifier(&cpu_notifier);
 }
 
 module_init(sysdig_init);
 module_exit(sysdig_exit);
 module_param(max_consumers, uint, 0444);
 MODULE_PARM_DESC(max_consumers, "Maximum number of consumers that can simultaneously open the devices");
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 module_param(verbose, bool, 0444);
+#endif
 MODULE_PARM_DESC(verbose, "Enable verbose logging");
