@@ -65,6 +65,7 @@ struct syscall_evt_pair {
  * We have one of these for each CPU.
  */
 struct ppm_ring_buffer_context {
+	bool cpu_online;
 	bool open;
 	bool capture_enabled;
 	struct ppm_ring_buffer_info *info;
@@ -91,13 +92,18 @@ struct ppm_consumer_t {
 	volatile int need_to_insert_drop_e;
 	volatile int need_to_insert_drop_x;
 	struct list_head node;
+	struct ppm_proclist_info *proclist_info;
 };
 
 #define STR_STORAGE_SIZE PAGE_SIZE
 
 /*
  * Global functions
+ *
+ * These are analogous to get_user(), copy_from_user() and strncpy_from_user(),
+ * but they can't sleep, barf on page fault or be preempted
  */
+#define ppm_get_user(x, ptr) ({ ppm_copy_from_user(&x, ptr, sizeof(x)) ? -EFAULT : 0; })
 unsigned long ppm_copy_from_user(void *to, const void __user *from, unsigned long n);
 long ppm_strncpy_from_user(char *to, const char __user *from, unsigned long n);
 
