@@ -19,8 +19,8 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #define pr_fmt(fmt)	KBUILD_MODNAME ": " fmt
 
 #include <linux/compat.h>
+#include <linux/kobject.h>
 #include <linux/cdev.h>
-#include <asm/syscall.h>
 #include <net/sock.h>
 #include <net/af_unix.h>
 #include <linux/ip.h>
@@ -34,6 +34,13 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #include <linux/module.h>
 #include <linux/kernel.h>
 #include <asm/mman.h>
+#include <linux/in.h>
+#if LINUX_VERSION_CODE <= KERNEL_VERSION(2, 6, 20)
+#include <linux/mount.h>
+#include "ppm_syscall.h"
+#else
+#include <asm/syscall.h>
+#endif
 
 #include "ppm_ringbuffer.h"
 #include "ppm_events_public.h"
@@ -261,20 +268,20 @@ inline u32 compute_snaplen(struct event_filler_arguments *args, char *buf, u32 l
 								return 2000;
 							}
 						}
-					} else if (( lookahead_size >= 4 && buf[1] == 0 && buf[2] == 0 && buf[2] == 0) || /* matches command */
-							   (lookahead_size >= 16 && ( *(int32_t*)(buf+12) == 1 || /* matches header */
-									   *(int32_t*)(buf+12) == 2001 ||
-									   *(int32_t*)(buf+12) == 2002 ||
-									   *(int32_t*)(buf+12) == 2003 ||
-									   *(int32_t*)(buf+12) == 2004 ||
-									   *(int32_t*)(buf+12) == 2005 ||
-									   *(int32_t*)(buf+12) == 2006 ||
-									   *(int32_t*)(buf+12) == 2007 )
+					} else if ((lookahead_size >= 4 && buf[1] == 0 && buf[2] == 0 && buf[2] == 0) || /* matches command */
+							   (lookahead_size >= 16 && (*(int32_t *)(buf+12) == 1 || /* matches header */
+									   *(int32_t *)(buf+12) == 2001 ||
+									   *(int32_t *)(buf+12) == 2002 ||
+									   *(int32_t *)(buf+12) == 2003 ||
+									   *(int32_t *)(buf+12) == 2004 ||
+									   *(int32_t *)(buf+12) == 2005 ||
+									   *(int32_t *)(buf+12) == 2006 ||
+									   *(int32_t *)(buf+12) == 2007)
 							   )
 							) {
 						sockfd_put(sock);
 						return 2000;
-					} else if ( dport == PPM_PORT_STATSD ) {
+					} else if (dport == PPM_PORT_STATSD) {
 						sockfd_put(sock);
 						return 2000;
 					} else {
@@ -524,6 +531,7 @@ int val_to_ring(struct event_filler_arguments *args, uint64_t val, u16 val_len,
 	case PT_UINT32:
 	case PT_UID:
 	case PT_GID:
+	case PT_SIGSET:
 		if (likely(args->arg_data_size >= sizeof(u32))) {
 			*(u32 *)(args->buffer + args->arg_data_offset) = (u32)val;
 			len = sizeof(u32);
@@ -608,6 +616,7 @@ int val_to_ring(struct event_filler_arguments *args, uint64_t val, u16 val_len,
  * of buf.
  * Buf must be at least 1 page in size.
  */
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20)
 char *npm_getcwd(char *buf, unsigned long bufsize)
 {
 	struct path pwd;
@@ -633,6 +642,28 @@ char *npm_getcwd(char *buf, unsigned long bufsize)
 
 	return res;
 }
+#else /* LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 20) */
+char *npm_getcwd(char *buf, unsigned long bufsize)
+{
+	struct dentry *dentry;
+	struct vfsmount *mnt;
+	char *res;
+
+	ASSERT(bufsize >= PAGE_SIZE - 1);
+
+	read_lock(&current->fs->lock);
+	mnt = mntget(current->fs->pwdmnt);
+	dentry = dget(current->fs->pwd);
+	read_unlock(&current->fs->lock);
+
+	res = d_path(dentry, mnt, buf, bufsize);
+
+	if (IS_ERR(res))
+		res = NULL;
+
+	return res;
+}
+#endif
 
 static inline u8 socket_family_to_scap(u8 family)
 {
@@ -680,9 +711,13 @@ static inline u8 socket_family_to_scap(u8 family)
 		return PPM_AF_ECONET;
 	} else if (family == AF_ATMSVC) {
 		return PPM_AF_ATMSVC;
-	} else if (family == AF_RDS) {
+	}
+#ifdef AF_RDS
+	else if (family == AF_RDS) {
 		return PPM_AF_RDS;
-	} else if (family == AF_SNA) {
+	}
+#endif
+	else if (family == AF_SNA) {
 		return PPM_AF_SNA;
 	} else if (family == AF_IRDA) {
 		return PPM_AF_IRDA;
@@ -692,23 +727,39 @@ static inline u8 socket_family_to_scap(u8 family)
 		return PPM_AF_WANPIPE;
 	} else if (family == AF_LLC) {
 		return PPM_AF_LLC;
-	} else if (family == AF_CAN) {
+	}
+#ifdef AF_CAN
+	else if (family == AF_CAN) {
 		return PPM_AF_CAN;
-	} else if (family == AF_TIPC) {
+	}
+#endif
+	 else if (family == AF_TIPC) {
 		return PPM_AF_TIPC;
 	} else if (family == AF_BLUETOOTH) {
 		return PPM_AF_BLUETOOTH;
 	} else if (family == AF_IUCV) {
 		return PPM_AF_IUCV;
-	} else if (family == AF_RXRPC) {
+	}
+#ifdef AF_RXRPC
+	else if (family == AF_RXRPC) {
 		return PPM_AF_RXRPC;
-	} else if (family == AF_ISDN) {
+	}
+#endif
+#ifdef AF_ISDN
+	else if (family == AF_ISDN) {
 		return PPM_AF_ISDN;
-	} else if (family == AF_PHONET) {
+	}
+#endif
+#ifdef AF_PHONET
+	else if (family == AF_PHONET) {
 		return PPM_AF_PHONET;
-	} else if (family == AF_IEEE802154) {
+	}
+#endif
+#ifdef AF_IEEE802154
+	else if (family == AF_IEEE802154) {
 		return PPM_AF_IEEE802154;
 	}
+#endif
 #ifdef AF_CAIF
 	else if (family == AF_CAIF) {
 		return PPM_AF_CAIF;
@@ -1138,7 +1189,7 @@ int32_t parse_readv_writev_bufs(struct event_filler_arguments *args, const struc
 
 		/*
 		 * Size is the total size of the buffers provided by the user. The number of
-		 * received bytes can be smaller 
+		 * received bytes can be smaller
 		 */
 		if ((flags & PRB_FLAG_IS_WRITE) == 0)
 			if (size > retval)
@@ -1171,7 +1222,7 @@ int32_t parse_readv_writev_bufs(struct event_filler_arguments *args, const struc
 						ASSERT(bufsize >= retval);
 
 						/*
-						 * Copied all the data even if we haven't reached the 
+						 * Copied all the data even if we haven't reached the
 						 * end of the buffer.
 						 * Copy must stop here.
 						 */
