@@ -35,6 +35,9 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #include "chisel_api.h"
 #include "filter.h"
 #include "filterchecks.h"
+#ifdef HAS_ANALYZER
+#include "analyzer.h"
+#endif
 
 #ifdef HAS_CHISELS
 #define HAS_LUA_CHISELS
@@ -1206,5 +1209,113 @@ int lua_cbacks::exec(lua_State *ls)
 	return 0;
 }
 
+int lua_cbacks::log(lua_State *ls) 
+{
+	lua_getglobal(ls, "sichisel");
+
+	string message(lua_tostring(ls, 1));
+	string sevstr(lua_tostring(ls, 2));
+
+	sinsp_logger::severity sevcode = sinsp_logger::SEV_INFO;
+
+	if(sevstr == "debug")
+	{
+		sevcode = sinsp_logger::SEV_DEBUG;
+	}
+	else if(sevstr == "info")
+	{
+		sevcode = sinsp_logger::SEV_INFO;
+	}
+	else if(sevstr == "warning")
+	{
+		sevcode = sinsp_logger::SEV_WARNING;
+	}
+	else if(sevstr == "error")
+	{
+		sevcode = sinsp_logger::SEV_ERROR;
+	}
+	else if(sevstr == "critical")
+	{
+		sevcode = sinsp_logger::SEV_CRITICAL;
+	}
+
+	g_logger.log(message, sevcode);
+
+	return 0;
+}
+
+#ifdef HAS_ANALYZER
+int lua_cbacks::push_metric(lua_State *ls) 
+{
+	statsd_metric metric;
+	metric.m_type = statsd_metric::type_t::GAUGE;
+
+	lua_getglobal(ls, "sichisel");
+
+	sinsp_chisel* ch = (sinsp_chisel*)lua_touserdata(ls, -1);
+	lua_pop(ls, 1);
+
+	ASSERT(ch);
+	ASSERT(ch->m_lua_cinfo);
+
+	sinsp* inspector = ch->m_inspector;
+
+	//
+	// tags
+	//
+	if(lua_istable(ls, 3))
+	{
+		lua_pushnil(ls);
+
+		while(lua_next(ls, 3) != 0) 
+		{
+			string tag = lua_tostring(ls, -1);
+			metric.m_tags[tag] = "";
+			lua_pop(ls, 1);
+		}
+
+		lua_pop(ls, 1);
+	}
+	else
+	{
+		string err = "error in chisel " + ch->m_filename + ": third argument must be a table";
+		fprintf(stderr, "%s\n", err.c_str());
+		throw sinsp_exception("chisel error");
+	}
+
+	//
+	// Name
+	//
+	if(lua_isstring(ls, 1))
+	{
+		metric.m_name = lua_tostring(ls, 1);
+	}
+	else
+	{
+		string err = "errord in chisel " + ch->m_filename + ": first argument must be a string";
+		fprintf(stderr, "%s\n", err.c_str());
+		throw sinsp_exception("chisel error");
+	}
+
+	//
+	// Value
+	//
+	if(lua_isnumber(ls, 2))
+	{
+		metric.m_value = lua_tonumber(ls, 2);
+	}
+	else
+	{
+		string err = "errord in chisel " + ch->m_filename + ": second argument must be a number";
+		fprintf(stderr, "%s\n", err.c_str());
+		throw sinsp_exception("chisel error");
+	}
+
+	inspector->m_analyzer->add_chisel_metric(&metric);
+
+	return 0;
+}
+
+#endif // HAS_ANALYZER
 #endif // HAS_LUA_CHISELS
 #endif // HAS_CHISELS
