@@ -97,7 +97,7 @@ public:
 	//
 	virtual Json::Value extract_as_js(sinsp_evt *evt, OUT uint32_t* len)
 	{
-		return Json::Value::null;
+		return Json::Value::nullRef;
 	}
 
 	//
@@ -240,6 +240,11 @@ public:
 		TYPE_UID = 19,
 		TYPE_CONTAINERNAME = 20,
 		TYPE_CONTAINERDIRECTORY = 21,
+		TYPE_PROTO = 22,
+		TYPE_CLIENTPROTO = 23,
+		TYPE_SERVERPROTO = 24,
+		TYPE_LPROTO = 25,
+		TYPE_RPROTO = 26
 	};
 
 	enum fd_type
@@ -379,42 +384,43 @@ public:
 		TYPE_TYPE = 17,
 		TYPE_TYPE_IS = 18,
 		TYPE_SYSCALL_TYPE = 19,
-		TYPE_CPU = 20,
-		TYPE_ARGS = 21,
-		TYPE_ARGSTR = 22,
-		TYPE_ARGRAW = 23,
-		TYPE_INFO = 24,
-		TYPE_BUFFER = 25,
-		TYPE_BUFLEN = 26,
-		TYPE_RESSTR = 27,
-		TYPE_RESRAW = 28,
-		TYPE_FAILED = 29,
-		TYPE_ISIO = 30,
-		TYPE_ISIO_READ = 31,
-		TYPE_ISIO_WRITE = 32,
-		TYPE_IODIR = 33,
-		TYPE_ISWAIT = 34,
-		TYPE_WAIT_LATENCY = 35,
-		TYPE_ISSYSLOG = 36,
-		TYPE_COUNT = 37,
-		TYPE_COUNT_ERROR = 38,
-		TYPE_COUNT_ERROR_FILE = 39,
-		TYPE_COUNT_ERROR_NET = 40,
-		TYPE_COUNT_ERROR_MEMORY = 41,
-		TYPE_COUNT_ERROR_OTHER = 42,
-		TYPE_COUNT_EXIT = 43,
-		TYPE_COUNT_PROCINFO = 44,
-		TYPE_COUNT_THREADINFO = 45,
-		TYPE_AROUND = 46,
-		TYPE_ABSPATH = 47,
-		TYPE_BUFLEN_IN = 48,
-		TYPE_BUFLEN_OUT = 49,
-		TYPE_BUFLEN_FILE = 50,
-		TYPE_BUFLEN_FILE_IN = 51,
-		TYPE_BUFLEN_FILE_OUT = 52,
-		TYPE_BUFLEN_NET = 53,
-		TYPE_BUFLEN_NET_IN = 54,
-		TYPE_BUFLEN_NET_OUT = 55,
+		TYPE_CATEGORY = 20,
+		TYPE_CPU = 21,
+		TYPE_ARGS = 22,
+		TYPE_ARGSTR = 23,
+		TYPE_ARGRAW = 24,
+		TYPE_INFO = 25,
+		TYPE_BUFFER = 26,
+		TYPE_BUFLEN = 27,
+		TYPE_RESSTR = 28,
+		TYPE_RESRAW = 29,
+		TYPE_FAILED = 30,
+		TYPE_ISIO = 31,
+		TYPE_ISIO_READ = 32,
+		TYPE_ISIO_WRITE = 33,
+		TYPE_IODIR = 34,
+		TYPE_ISWAIT = 35,
+		TYPE_WAIT_LATENCY = 36,
+		TYPE_ISSYSLOG = 37,
+		TYPE_COUNT = 38,
+		TYPE_COUNT_ERROR = 39,
+		TYPE_COUNT_ERROR_FILE = 40,
+		TYPE_COUNT_ERROR_NET = 41,
+		TYPE_COUNT_ERROR_MEMORY = 42,
+		TYPE_COUNT_ERROR_OTHER = 43,
+		TYPE_COUNT_EXIT = 44,
+		TYPE_COUNT_PROCINFO = 45,
+		TYPE_COUNT_THREADINFO = 46,
+		TYPE_AROUND = 47,
+		TYPE_ABSPATH = 48,
+		TYPE_BUFLEN_IN = 49,
+		TYPE_BUFLEN_OUT = 50,
+		TYPE_BUFLEN_FILE = 51,
+		TYPE_BUFLEN_FILE_IN = 52,
+		TYPE_BUFLEN_FILE_OUT = 53,
+		TYPE_BUFLEN_NET = 54,
+		TYPE_BUFLEN_NET_IN = 55,
+		TYPE_BUFLEN_NET_OUT = 56,
 	};
 
 	sinsp_filter_check_event();
@@ -624,4 +630,30 @@ private:
 	uint64_t m_cnt;
 };
 
+//
+// fdlist checks
+//
+class sinsp_filter_check_fdlist : public sinsp_filter_check
+{
+public:
+	enum check_type
+	{
+		TYPE_FDNUMS = 0,
+		TYPE_FDNAMES = 1,
+		TYPE_CLIENTIPS = 2,
+		TYPE_SERVERIPS = 3,
+		TYPE_CLIENTPORTS = 4,
+		TYPE_SERVERPORTS = 5,
+	};
+
+	sinsp_filter_check_fdlist();
+	sinsp_filter_check* allocate_new();
+	int32_t parse_field_name(const char* str, bool alloc_state);
+	uint8_t* extract(sinsp_evt *evt, OUT uint32_t* len);
+
+private:
+	string m_strval;
+	char m_addrbuff[100];
+};
+
 #endif // HAS_FILTERING
