@@ -187,6 +187,7 @@ void sinsp_parser::process_event(sinsp_evt *evt)
 		break;
 	case PPME_SYSCALL_SELECT_E:
 	case PPME_SYSCALL_POLL_E:
+	case PPME_SYSCALL_PPOLL_E:
 	case PPME_SYSCALL_EPOLLWAIT_E:
 		parse_select_poll_epollwait_enter(evt);
 		break;
@@ -226,7 +227,9 @@ void sinsp_parser::process_event(sinsp_evt *evt)
 		parse_connect_exit(evt);
 		break;
 	case PPME_SOCKET_ACCEPT_X:
+	case PPME_SOCKET_ACCEPT_5_X:
 	case PPME_SOCKET_ACCEPT4_X:
+	case PPME_SOCKET_ACCEPT4_5_X:
 		parse_accept_exit(evt);
 		break;
 	case PPME_SYSCALL_CLOSE_E:
@@ -303,6 +306,9 @@ void sinsp_parser::process_event(sinsp_evt *evt)
 	case PPME_CONTAINER_E:
 		parse_container_evt(evt);
 		break;
+	case PPME_CPU_HOTPLUG_E:
+		parse_container_evt(evt);
+		break;
 	default:
 		break;
 	}
@@ -453,6 +459,7 @@ bool sinsp_parser::reset(sinsp_evt *evt)
 			ASSERT(evt->get_param_info(0)->type == PT_FD);
 
 			evt->m_tinfo->m_lastevent_fd = *(int64_t *)parinfo->m_val;
+			evt->m_fdinfo = evt->m_tinfo->get_fd(evt->m_tinfo->m_lastevent_fd);
 		}
 
 		evt->m_tinfo->m_latency = 0;
@@ -1162,7 +1169,7 @@ void sinsp_parser::parse_clone_exit(sinsp_evt *evt)
 	else
 	{
 		tinfo.m_vtid = tinfo.m_tid;
-		tinfo.m_vpid = tinfo.m_vpid;
+		tinfo.m_vpid = tinfo.m_pid;
 	}
 
 	//
@@ -1686,13 +1693,64 @@ void sinsp_parser::parse_socket_exit(sinsp_evt *evt)
 
 void sinsp_parser::parse_bind_exit(sinsp_evt *evt)
 {
+	sinsp_evt_param *parinfo;
+	int64_t retval;
 	const char *parstr;
+	uint8_t *packed_data;
+	uint8_t family;
 
 	if(evt->m_fdinfo == NULL)
 	{
 		return;
 	}
 
+	parinfo = evt->get_param(0);
+	ASSERT(parinfo->m_len == sizeof(uint64_t));
+	retval = *(int64_t*)parinfo->m_val;
+
+	if(retval < 0)
+	{
+		return;
+	}
+
+	parinfo = evt->get_param(1);
+	if(parinfo->m_len == 0)
+	{
+		//
+		// No address, there's nothing we can really do with this.
+		// This happens for socket types that we don't support, so we have the assertion
+		// to make sure that this is not a type of socket that we support.
+		//
+		ASSERT(!(evt->m_fdinfo->is_unix_socket() || evt->m_fdinfo->is_ipv4_socket()));
+		return;
+	}
+
+	packed_data = (uint8_t*)parinfo->m_val;
+
+	family = *packed_data;
+
+	//
+	// Update the FD info with this tuple, assume that if port > 0, means that
+	// the socket is used for listening
+	//
+	if(family == PPM_AF_INET)
+	{
+		uint16_t port = *(uint16_t *)(packed_data + 5);
+		if(port > 0)
+		{
+			evt->m_fdinfo->m_type = SCAP_FD_IPV4_SERVSOCK;
+			evt->m_fdinfo->m_sockinfo.m_ipv4serverinfo.m_port = port;
+		}
+	}
+	else if (family == PPM_AF_INET6)
+	{
+		uint16_t port = *(uint16_t *)(packed_data + 17);
+		if(port > 0)
+		{
+			evt->m_fdinfo->m_type = SCAP_FD_IPV6_SERVSOCK;
+			evt->m_fdinfo->m_sockinfo.m_ipv6serverinfo.m_port = port;
+		}
+	}
 	//
 	// Update the name of this socket
 	//
@@ -2461,7 +2519,8 @@ void sinsp_parser::parse_rw_exit(sinsp_evt *evt)
 
 						sinsp_utils::sockinfo_to_str(&evt->m_fdinfo->m_sockinfo,
 							fdtype, &evt->m_paramstr_storage[0],
-							(uint32_t)evt->m_paramstr_storage.size());
+							(uint32_t)evt->m_paramstr_storage.size(),
+							m_inspector->m_hostname_and_port_resolution_enabled);
 
 						evt->m_fdinfo->m_name = &evt->m_paramstr_storage[0];
 					}
@@ -2555,7 +2614,8 @@ void sinsp_parser::parse_rw_exit(sinsp_evt *evt)
 
 						sinsp_utils::sockinfo_to_str(&evt->m_fdinfo->m_sockinfo,
 							fdtype, &evt->m_paramstr_storage[0],
-							(uint32_t)evt->m_paramstr_storage.size());
+							(uint32_t)evt->m_paramstr_storage.size(),
+							m_inspector->m_hostname_and_port_resolution_enabled);
 
 						evt->m_fdinfo->m_name = &evt->m_paramstr_storage[0];
 					}
@@ -3351,3 +3411,13 @@ void sinsp_parser::parse_container_evt(sinsp_evt *evt)
 
 	m_inspector->m_container_manager.add_container(container_info);
 }
+
+void sinsp_parser::parse_cpu_hotplug_enter(sinsp_evt *evt)
+{
+#ifdef HAS_ANALYZER
+	if(m_inspector->is_live())
+	{
+		throw sinsp_exception("CPUs configuration change detected. Aborting.");
+	}
+#endif
+}
