@@ -108,6 +108,16 @@ class sinsp_protodecoder;
 
 vector<string> sinsp_split(const string &s, char delim);
 
+/*!
+  \brief Information about a chisel
+*/
+class sinsp_chisel_details
+{
+public:
+	string m_name;
+	vector<pair<string, string>> m_args;
+};
+
 /*!
   \brief Information about a group of filter/formatting fields.
 */
@@ -546,6 +556,17 @@ public:
 	*/
 	void set_fatfile_dump_mode(bool enable_fatfile);
 
+	/*!
+	  \brief Set whether Sysdig should resolve hostnames and port protocols or not.
+
+	  \note Sysdig can use the system library functions getservbyport and so to
+	   resolve protocol names and domain names.
+	  
+	  \param disable If set to false it will enable this function and use plain
+	   numerical values.
+	*/
+	void set_hostname_and_port_resolution_mode(bool enable);
+
 	/*!
 	  \brief Sets the max length of event argument strings. 
 
@@ -629,7 +650,7 @@ public:
 
 	sinsp_parser* get_parser();
 
-	bool setup_cycle_writer(string base_file_name, int rollover_mb, int duration_seconds, int file_limit, bool do_cycle, bool compress);
+	bool setup_cycle_writer(string base_file_name, int rollover_mb, int duration_seconds, int file_limit, unsigned long event_limit, bool compress);
 	void import_ipv4_interface(const sinsp_ipv4_ifinfo& ifinfo);
 	void add_meta_event(sinsp_evt *metaevt);
 	void add_meta_event_and_repeat(sinsp_evt *metaevt);
@@ -669,6 +690,7 @@ private:
 	string m_input_filename;
 	bool m_isdebug_enabled;
 	bool m_isfatfile_enabled;
+	bool m_hostname_and_port_resolution_enabled;
 	uint32_t m_max_evt_output_len;
 	bool m_compress;
 	sinsp_evt m_evt;
@@ -803,7 +825,8 @@ private:
 	friend class sinsp_worker;
 	friend class sinsp_table;
 	friend class curses_textbox;
-
+	friend class sinsp_filter_check_fd;
+	
 	template<class TKey,class THash,class TCompare> friend class sinsp_connection_manager;
 };
 
